@@ -17,10 +17,13 @@ macro_rules! skip_assert_initialized {
     () => {};
 }
 
-mod auto;
-
 #[allow(unused_imports)]
 use gtk; // Required for the documentation to build without warnings
 
-pub use self::auto::functions::*;
+mod auto;
+
+pub use auto::functions::*;
 pub use auto::*;
+
+mod manual;
+pub use manual::*;
